@@ -30,12 +30,14 @@
 #'
 #' @export
 #'
+#' @family posterior quantities
+#'
 assign_cluster <- function(model_fit, burnin = model_fit$burnin, soft = TRUE, expand = FALSE) {
   if (is.null(burnin)) {
     stop("Please specify the burnin.")
   }
   if (is.null(model_fit$cluster_assignment)) {
-    stop("Rerun compute_mallows with save_clus=TRUE.")
+    stop("No cluster assignments.")
   }
   stopifnot(burnin < model_fit$nmc)
 
