@@ -13,7 +13,7 @@ NULL
 #' Check if a vector is a permutation
 #' @param vec a vector
 #' @return TRUE if vec is a permutation
-#' @keywords internal
+#' @noRd
 validate_permutation <- function(vec) {
   if (!any(is.na(vec))) {
     return(all(sort(vec) == seq_along(vec)))
@@ -25,10 +25,6 @@ validate_permutation <- function(vec) {
   }
 }
 
-# Function for getting an x axis without decimals.
-# Modified from https://stackoverflow.com/questions/21061653/creating-a-density-histogram-in-ggplot2
-scalefun <- function(x) sprintf("%d", as.integer(x))
-
 #' Prepare partition functions
 #'
 #' Utility function for estimating partition function of the Mallows model.
@@ -43,6 +39,7 @@ scalefun <- function(x) sprintf("%d", as.integer(x))
 #' estimates.
 #'
 #' @export
+#' @family preprocessing
 #'
 prepare_partition_function <- function(logz_estimate = NULL, metric, n_items) {
   # First, has the user supplied an estimate?
