@@ -21,14 +21,11 @@
 #' @param ... Other arguments passed to \code{plot} (not used).
 #'
 #' @export
+#' @importFrom stats density
 #'
 #' @example /inst/examples/plot.BayesMallows_example.R
-#'
+#' @family posterior quantities
 plot.BayesMallows <- function(x, burnin = x$burnin, parameter = "alpha", items = NULL, ...) {
-  # Note, the first argument must be named x, otherwise R CMD CHECK will
-  # issue a warning. This is because plot.BayesMallows must have the same
-  # required arguments as graphics::plot.
-
   if (is.null(burnin)) {
     stop("Please specify the burnin.")
   }
@@ -63,19 +60,11 @@ plot.BayesMallows <- function(x, burnin = x$burnin, parameter = "alpha", items =
 
     df <- x$rho[x$rho$iteration > burnin & x$rho$item %in% items, , drop = FALSE]
 
-    # Compute the density, rather than the count, since the latter
-    # depends on the number of Monte Carlo samples
-    df <- aggregate(
-      list(n = df$iteration),
-      list(cluster = df$cluster, item = df$item, value = df$value),
-      FUN = length
-    )
-    df$pct <- df$n / sum(df$n)
-
     # Finally create the plot
-    p <- ggplot2::ggplot(df, ggplot2::aes(x = .data$value, y = .data$pct)) +
-      ggplot2::geom_col() +
-      ggplot2::scale_x_continuous(labels = scalefun) +
+    p <- ggplot2::ggplot(df, ggplot2::aes(.data$value)) +
+      ggplot2::geom_histogram(
+        bins = x$n_items, ggplot2::aes(y = ggplot2::after_stat(density)),
+        fill = "black", col = "gray") +
       ggplot2::xlab("rank") +
       ggplot2::ylab("Posterior probability")
 
@@ -96,7 +85,7 @@ plot.BayesMallows <- function(x, burnin = x$burnin, parameter = "alpha", items =
       ggplot2::facet_wrap(~ .data$cluster)
   } else if (parameter == "cluster_assignment") {
     if (is.null(x$cluster_assignment)) {
-      stop("Please rerun compute_mallows with save_clus = TRUE")
+      stop("No cluster assignments.")
     }
 
     # First get one cluster per assessor, and sort these
