@@ -15,7 +15,6 @@ using namespace arma;
 //' a Metropolis-Hastings algorithm.
 //'
 //' @param rho0 Vector specifying the latent consensus ranking.
-//' @param obs_freq Vector of observation frequencies (weights) to apply to each sample.
 //' @param alpha0 Scalar specifying the scale parameter.
 //' @param n_samples Integer specifying the number of random samples to generate.
 //' @param burnin Integer specifying the number of iterations to discard as burn-in.
@@ -24,9 +23,7 @@ using namespace arma;
 //' @param leap_size Integer specifying the step size of the leap-and-shift proposal distribution.
 //' @param metric Character string specifying the distance measure to use. Available
 //' options are \code{"footrule"} (default), \code{"spearman"}, \code{"cayley"}, \code{"hamming"},
-//' \code{"kendall"}, and \code{"ulam"}. For sampling from the Mallows model with Cayley, Hamming, Kendall,
-//' and Ulam distances
-//' the \code{PerMallows} package \insertCite{irurozki2016}{BayesMallows} can also be used.
+//' \code{"kendall"}, and \code{"ulam"}.
 //'
 //' @keywords internal
 //'
@@ -35,7 +32,6 @@ using namespace arma;
 // [[Rcpp::export]]
 arma::mat rmallows(
     arma::vec rho0,
-    arma::vec obs_freq,
     double alpha0,
     int n_samples,
     int burnin,
@@ -77,7 +73,7 @@ arma::mat rmallows(
 
     // Compute the distances to current and proposed ranks
     double dist_new = get_rank_distance(rho0(indices), rho_proposal(indices), metric);
-    double dist_old = rank_dist_sum(rho0(indices), rho_iter(indices), metric, obs_freq);
+    double dist_old = rank_dist_sum(rho0(indices), rho_iter(indices), metric, ones(rho0.n_elem));
 
     // Metropolis-Hastings ratio
     double ratio = - alpha0 / n_items * (dist_new - dist_old) +
